import React from 'react';
import logo from '@assets/images/logo.png';
import { Grid } from 'antd-mobile';
import { initDate } from '@utils/index.js';
/**
 * @刘丹: 大屏叫号
 */
class BigScreen extends React.Component {
  constructor() {
    super();
    this.state = {
      dateStr: {},
      patList: [],
      current: 1,
      pageSize: 6, // 一页显示的数据条数
      timer: null, // 切换页面显示的定时器
      // 模拟数据
      tempList: [{ 'roomDesc': '一诊室', 'docName': '医生1','callMsg':{'callPat':[{'patCallNo':'','patName':'患者1'}],'waitPat':[{'patCallNo':'','patName':'患者2a'}]}},
       { 'roomDesc': '二诊室', 'docName': '医生2','callMsg':{'callPat':[{'patCallNo':'','patName':'患者2'}],'waitPat':[{'patCallNo':'','patName':'患者2v'}]}},
       { 'roomDesc': '三诊室', 'docName': '医生3','callMsg':{'callPat':[{'patCallNo':'','patName':'患者3'}],'waitPat':[{'patCallNo':'','patName':'患者2d'}]}},
       { 'roomDesc': '四诊室', 'docName': '医生4','callMsg':{'callPat':[{'patCallNo':'','patName':'患者4'}],'waitPat':[{'patCallNo':'','patName':'患者2g'}]}},
       { 'roomDesc': '五诊室', 'docName': '医生5','callMsg':{'callPat':[{'patCallNo':'','patName':'患者5'}],'waitPat':[{'patCallNo':'','patName':'患者2f'}]}},
       { 'roomDesc': '六诊室', 'docName': '医生6','callMsg':{'callPat':[{'patCallNo':'','patName':'患者6'}],'waitPat':[{'patCallNo':'','patName':'患者2h'}]}},
       { 'roomDesc': '七诊室', 'docName': '医生7','callMsg':{'callPat':[{'patCallNo':'','patName':'患者7'}],'waitPat':[{'patCallNo':'','patName':'患者2y'}]}}],
    };
  }
  componentDidMount() {
    this.initDate();
    document.querySelector('html').style.fontSize = '20px';
    this.initScroll();
  }
  componentDidUpdate(prev) {
    if (prev.patListArea != this.props.patListArea) {
      this.setPatList();
    }
  }
  // 滚动设置就诊数据
  setPatList = () => {
    if (this.state.timer) {
      clearTimeout(this.state.timer);
    }
    this.setState({
      current: 0,
      totalPage: Math.ceil(this.props.patListArea?.length / this.state.pageSize),
    }, () => {
      if (this.props.patListArea?.length <= this.state.pageSize) {
        this.setState({
          patList: this.props.patListArea,
        });
      } else {
        const fn = () => {
          let current = this.state.current + 1;
          if (current > this.state.totalPage) {
            current = 1;
          }
          const { pageSize } = this.state;
          this.setState({
            current,
            patList: this.props.patListArea.slice((current - 1) * pageSize, current * pageSize),
          });
          // 10s切换
          const timer = setTimeout(fn, 6000);
          this.setState({
            timer,
          });
        };
        fn();
      }
    });
  };
  // 初始化滚动
  initScroll = () => {
    const parentDom = document.getElementById('patWrap');
    const style = window.getComputedStyle(parentDom);
    const parentH = parentDom.offsetHeight - parseInt(style.paddingTop) - parseInt(style.paddingBottom) - 50;
    const childH = parentDom.children[0].offsetHeight;
    const pageSize = Math.floor(parentH / childH) - 1;
    this.setState({
      pageSize,
    });
  };
  initDate = () => {
    this.setState({
      dateStr: initDate(),
    });
    setTimeout(() => {
      this.initDate();
    }, 3000);
  };
  render() {
    const { dateStr } = this.state;
    const { userData } = this.props;
    return (
      <div className='page-body big'>
        <div className='header'>
          <img
            src={this.props.hosLogo || logo}
            alt='Logo'
            className='logo'
            onError={(e) => {
              e.target.src = `${logo}`;
            }}
          />
          <span className='room-name'>{ userData.areaDesc || userData.locDesc}</span>
          <span className='heaer-btn'>
            <span className='date'>{ dateStr.dateNow}</span>
            <br /> {dateStr.weekNow} {  dateStr.timeNow}
          </span>
        </div>
        <div className='table section' id="patWrap">
          <Grid columns={5} gap={8}>
            <Grid.Item span={1}>
              <div className='table-header'>{ userData.locDesc === '验光配镜分诊区' ? '验光室':'诊室' }</div>
            </Grid.Item >
            <Grid.Item span={1}>
              <div className='table-header'>{ userData.locDesc === '验光配镜分诊区' ? '验光师':'医生' }</div>
            </Grid.Item >
            <Grid.Item span={1}>
              <div className='table-header'>当前就诊</div>
            </Grid.Item >
             <Grid.Item span={2}>
              <div className='table-header'>准备就诊</div>
            </Grid.Item >
          </Grid>
          {this.state.patList.map((item,index) => {
            return (<Grid columns={5} gap={8} key={index}>
              <Grid.Item span={1}>
                <div className='table-content'>{item.roomDesc}</div>
              </Grid.Item >
              <Grid.Item span={1}>
                <div className='table-content'>{item.docName || '-'}</div>
              </Grid.Item >
              <Grid.Item span={1}>
                <div className='table-content'>
                  {item?.callMsg?.callPat?.map(v => v.patName).join((','))}
                </div>
              </Grid.Item >
              <Grid.Item span={2}>
                <div className='table-content'>
                  {item?.callMsg?.waitPat?.map(v => v.patName).join((','))}
                </div>
              </Grid.Item >
            </Grid>);
          })}
        </div>
        <div className='footer'>过号患者:{ this.props.delayPat}</div>
      </div>
    );
  }
}

export default BigScreen;
